import connexion
import six

from swagger_server import util


def tags_count_get():  # noqa: E501
    """Get number of tags present in MDB

     # noqa: E501


    :rtype: object
    """
    return 'do some magic!'


def tags_get():  # noqa: E501
    """Get all tag nodes in MDB

     # noqa: E501


    :rtype: object
    """
    return 'do some magic!'
